<?php

namespace App\Controller;

use App\Entity\User;
use App\Libs\Breadcrumb;
use App\Libs\NavList;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\PasswordHasher\Hasher\UserPasswordHasherInterface;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Attribute\CurrentUser;

class StaffController extends AbstractController
{
    public function __construct(
        private readonly EntityManagerInterface $entityManager,
        private readonly UserPasswordHasherInterface $userPasswordHasher,
        private array $navLinks = []
    ) {
        $this->navLinks = NavList::LIST;
        $this->navLinks['staff_dashboard'] = NavList::PRESENT_LINK;
    }

    #[Route('/staff-dashboard', name: 'app_staff_dashboard')]
    public function staffDashboard(#[CurrentUser()] User $user): Response
    {
        return $this->render(
            'internal/staff/staff-dashboard.html.twig',
            array_merge(
                $this->navLinks,
                [
                    'breadcrumbs' => [
                        new Breadcrumb('', 'Staff Dashboard')
                    ],
                    'notifications' => $user->retrieveUnreadNotifications(),
                ]
            )
        );
    }
}
